SunriseSunsetData class
Constructors
-
SunriseSunsetData.fromJSON(Map<
String, dynamic> json) -
factory
Properties
- astronomicalTwilightBegin → DateTime
-
final
- astronomicalTwilightEnd → DateTime
-
final
- civilTwilightBegin → DateTime
-
final
- civilTwilightEnd → DateTime
-
final
- dayLength → int
-
Expressed in seconds
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nauticalTwilightBegin → DateTime
-
final
- nauticalTwilightEnd → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- solarNoon → DateTime
-
final
- sunrise → DateTime
-
final
- sunset → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited